@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.036';
+$HackaMol::Molecule::VERSION = '0.037';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -29,16 +29,13 @@ has 'groups' => (
         get_groups     => 'get',
         set_groups     => 'set',
         all_groups     => 'elements',
+        sort_groups    => 'sort',
+        insert_groups  => 'insert',
         count_groups   => 'count',
         delete_groups  => 'delete',
         clear_groups   => 'clear',
         select_groups  => 'grep',
         map_groups     => 'map',
-        first_groups   => 'first',
-        sort_groups    => 'sort',
-        splice_groups  => 'splice',
-        insert_groups  => 'insert',
-        shuffle_groups => 'shuffle',
     },
 );
 
@@ -56,6 +53,24 @@ sub BUILD {
     return;
 }
 
+after 'push_groups' => sub {
+# if you push a group onto a molecule, the atoms should be added unless they 
+# exist!
+  my $self = shift;
+  my @groups = @_;
+  foreach my $group (@groups){
+    foreach my $atom ($group->all_atoms){
+      unless (grep {$atom == $_} $self->all_atoms){
+        $self->push_atoms($atom);
+      }  
+ # debug
+ #     else {
+ #       print "found it\n $atom \n" if grep {$atom == $_} $self->all_atoms;   
+ #     }
+    }
+  }
+};
+
 sub charge {
   my $self = shift;
   my $t = $self->t;
@@ -246,7 +261,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.036
+version 0.037
 
 =head1 SYNOPSIS
 
