@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.036';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.037';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -22,13 +22,10 @@ has 'atoms' => (
         push_atoms    => 'push',
         select_atoms  => 'grep',
         map_atoms     => 'map',
-        first_atoms   => 'first',
         sort_atoms    => 'sort',
-        splice_atoms  => 'splice',
-        insert_atoms  => 'insert',
-        shuffle_atoms => 'shuffle',
         get_atoms     => 'get',
         set_atoms     => 'set',
+        insert_atoms  => 'insert',
         delete_atoms  => 'delete',
         all_atoms     => 'elements',
         count_atoms   => 'count',
@@ -385,7 +382,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.036
+version 0.037
 
 =head1 SYNOPSIS
 
